==> mighttpd2-4.0.3-212-x86_64.pkg.tar.zst: usr/share/haskell/register/mighttpd2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mighttpd2
version:              4.0.3
visibility:           public
id:                   mighttpd2-4.0.3-2guJ1ifRNgB34Y0Syp69yl
key:                  mighttpd2-4.0.3-2guJ1ifRNgB34Y0Syp69yl
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://kazu-yamamoto.github.io/mighttpd2/
synopsis:             High performance web server on WAI/warp
description:
    High performance web server to handle static
    files and CGI on WAI/warp.
    Reverse proxy functionality is also provided
    to connect web applications behind.

category:             Network, Web
abi:                  fe0a057e78ed45b5ec2bc1c1bc7f9216
exposed:              True
exposed-modules:
    Program.Mighty Program.Mighty.ByteString Program.Mighty.Config
    Program.Mighty.Dhall.Option Program.Mighty.Network
    Program.Mighty.Parser Program.Mighty.Process Program.Mighty.Report
    Program.Mighty.Resource Program.Mighty.Route Program.Mighty.Signal
    Program.Mighty.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/mighttpd2-4.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mighttpd2-4.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mighttpd2-4.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/mighttpd2
hs-libraries:         HSmighttpd2-4.0.3-2guJ1ifRNgB34Y0Syp69yl
depends:
    array-0.5.4.0 async-2.2.5-63qhz2egf712xrTPAnr2Zj
    auto-update-0.1.6-4DQohd9hYjG6wnn040LHar base-4.17.2.1
    byteorder-1.0.4-GnZZPnCtMLjHLa4McP5dl3 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-LMolnZwpRvW7BfRj8XMS7A
    conduit-1.3.6.1-HAJpY08cc65Cd4m5QP3X4q
    conduit-extra-1.3.6-CPHOsyPWtJ828Ihw7K9kVr
    dhall-1.42.1-DkMx8Nr4uBcCdN2pZl7J7j directory-1.3.7.1
    filepath-1.4.2.2 http-date-0.0.11-AGi76S9M9dtEElTGJQdkfD
    http-types-0.12.4-57pHf4hFiOh2bb0nmyfV8P
    network-3.1.4.0-82nHJL6Luo48oDimrIyJyV parsec-3.1.16.1
    resourcet-1.2.6-HbN0RV9wT5VCrWiuK0rjhN
    split-0.2.5-HpMLqVZDDpD6ikSNqZEnQ0
    streaming-commons-0.2.3.0-3nSr0O5rGhj3FyAyoP6GJ5 text-2.0.2
    unix-2.7.3 unix-time-0.4.16-HyqItAaU4OS97Wsaoufosq
    unliftio-0.2.25.1-AXRi31Q55nfHgGjBnzlMpR
    unordered-containers-0.2.20-LkuwqgGHy2J6l9MBSYA9kS
    wai-3.2.4-JjfNpwYIsY661HSR3DMIkW
    wai-app-file-cgi-3.1.10-Eu3P0WX1C9IGza6q5gcnJC
    warp-3.3.30-ER0vi0tLOq7CSmlAvCDXjt

haddock-interfaces:   /usr/share/doc/mighttpd2/html/mighttpd2.haddock
haddock-html:         /usr/share/doc/mighttpd2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> mighttpd2-4.0.3-213-x86_64.pkg.tar.zst: usr/share/haskell/register/mighttpd2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mighttpd2
version:              4.0.3
visibility:           public
id:                   mighttpd2-4.0.3-CNa7KW2jxaA5qCB306eUG5
key:                  mighttpd2-4.0.3-CNa7KW2jxaA5qCB306eUG5
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://kazu-yamamoto.github.io/mighttpd2/
synopsis:             High performance web server on WAI/warp
description:
    High performance web server to handle static
    files and CGI on WAI/warp.
    Reverse proxy functionality is also provided
    to connect web applications behind.

category:             Network, Web
abi:                  645d760ac558d980cb69707bb4d8176b
exposed:              True
exposed-modules:
    Program.Mighty Program.Mighty.ByteString Program.Mighty.Config
    Program.Mighty.Dhall.Option Program.Mighty.Network
    Program.Mighty.Parser Program.Mighty.Process Program.Mighty.Report
    Program.Mighty.Resource Program.Mighty.Route Program.Mighty.Signal
    Program.Mighty.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/mighttpd2-4.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mighttpd2-4.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mighttpd2-4.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/mighttpd2
hs-libraries:         HSmighttpd2-4.0.3-CNa7KW2jxaA5qCB306eUG5
depends:
    array-0.5.4.0 async-2.2.5-63qhz2egf712xrTPAnr2Zj
    auto-update-0.1.6-4DQohd9hYjG6wnn040LHar base-4.17.2.1
    byteorder-1.0.4-GnZZPnCtMLjHLa4McP5dl3 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-LMolnZwpRvW7BfRj8XMS7A
    conduit-1.3.6.1-HAJpY08cc65Cd4m5QP3X4q
    conduit-extra-1.3.6-CPHOsyPWtJ828Ihw7K9kVr
    dhall-1.42.1-GYPRq5sog4XHS9lOxTFhYI directory-1.3.7.1
    filepath-1.4.2.2 http-date-0.0.11-AGi76S9M9dtEElTGJQdkfD
    http-types-0.12.4-57pHf4hFiOh2bb0nmyfV8P
    network-3.1.4.0-82nHJL6Luo48oDimrIyJyV parsec-3.1.16.1
    resourcet-1.2.6-HbN0RV9wT5VCrWiuK0rjhN
    split-0.2.5-HpMLqVZDDpD6ikSNqZEnQ0
    streaming-commons-0.2.3.0-3nSr0O5rGhj3FyAyoP6GJ5 text-2.0.2
    unix-2.7.3 unix-time-0.4.16-HyqItAaU4OS97Wsaoufosq
    unliftio-0.2.25.1-AXRi31Q55nfHgGjBnzlMpR
    unordered-containers-0.2.20-LkuwqgGHy2J6l9MBSYA9kS
    wai-3.2.4-JjfNpwYIsY661HSR3DMIkW
    wai-app-file-cgi-3.1.10-HLmr5TReKccAZVxDjUM4yN
    warp-3.3.30-ER0vi0tLOq7CSmlAvCDXjt

haddock-interfaces:   /usr/share/doc/mighttpd2/html/mighttpd2.haddock
haddock-html:         /usr/share/doc/mighttpd2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
